-- Generate my Ace Addon
local QuestUnTracker = LibStub("AceAddon-3.0"):NewAddon("QuestUnTracker", "AceEvent-3.0")

-- Defaults for QuestUnTrackerDB
local defaults =
{
	profile =
	{
		normals = true,
		dailies = true,
	}
}

-- Easy DB reference
local globalDB

-- Options table for use of Ace-Config 3
local options =
{
    name = "Quest Un-Tracker",
    type = "group",
    args =
	{
		normalquests =
		{
			name = "Normal Quests",
			desc = "Enable un-tracking of normal quests.",
			type = "toggle",
			set = function(info, value) globalDB.normals = value end,
			get = function(info) return globalDB.normals end,
		},
		dailies =
		{
			name = "Dailies",
			desc = "Enable un-tracking of daily quests.",
			type = "toggle",
			set = function(info, value) globalDB.dailies = value end,
			get = function(info) return globalDB.dailies end,
		},
    },
}

function QuestUnTracker:OnInitialize()
	-- Register the DataBase
	self.db = LibStub("AceDB-3.0"):New("QuestUnTrackerDB", defaults, true);
	globalDB = self.db.global
	
	-- And register the options
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Quest Un-Tracker", options);

	-- And add the options table to the actual interface UI
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Quest Un-Tracker", "Quest Un-Tracker")

	-- Add the event
	QuestUnTracker:RegisterEvent("UNIT_QUEST_LOG_CHANGED")
	
	-- Get meta data to output version number
	print("Quest Un-Tracker v" .. GetAddOnMetadata(QuestUnTracker:GetName(), "Version") .. " loaded");
end

function QuestUnTracker:UNIT_QUEST_LOG_CHANGED(event, ...)
	-- Only event is UNIT_QUEST_LOG_CHANGED - argument for that event is unitID
	if not select(1, "...") == "player" then return end
	
	local numQuests = GetNumQuestLogEntries();
	local questIndex;

	for questIndex = 1, numQuests do
		local title, _, _, _, _, _, isComplete, isDaily, _ = GetQuestLogTitle(questIndex)
		local removeWatch = isComplete and IsQuestWatched(questIndex)
		
		-- Exceptions based on options
		if isDaily and not globalDB.dailies then removeWatch = false end
		if not isDaily and not globalDB.normals then removeWatch = false end
		
		if removeWatch then
			print("Quest '"..title.."' complete and removed from watch list.");
			RemoveQuestWatch(questIndex);
			WatchFrame_Update();
		end
	end
end
